@@ -2,7 +2,7 @@ package Bio::Graphics::Browser2;
 # $Id$
 # Globals and utilities for GBrowse and friends
 
-our $VERSION = '2.48';
+our $VERSION = '2.49';
 
 use strict;
 use warnings;
@@ -284,7 +284,9 @@ sub openid_secret {
 sub upload_db_adaptor {
     my $self = shift;
     my $adaptor = $self->setting(general=>'upload_db_adaptor') || $self->setting(general=>'userdb_adaptor');
-    warn "The upload_db_adaptor in your Gbrowse.conf file isn't in the DBI::<module> format: remember, it's not a connection string." if $adaptor =~ /^DBI/ && $adaptor !~ /(^DBI::+)/i;
+    $adaptor or return;
+    warn "The upload_db_adaptor in your Gbrowse.conf file isn't in the DBI::<module> format: remember, it's not a connection string." 
+	if $adaptor =~ /^DBI/ && $adaptor !~ /(^DBI::+)/i;
     return $adaptor;
 }
 sub upload_db_host {
