@@ -240,7 +240,7 @@ sub ACTION_reconfigure_track {
     my $track_name     = $q->param('track') or croak;
     my $semantic_label = $q->param('semantic_label');
 
-    $self->render->reconfigure_track($track_name,$semantic_label);
+    $self->render->reconfigure_track($q,$track_name,$semantic_label);
     $self->session->flush;
     $self->session->unlock;
     return ( 200, 'application/json', {} );
@@ -254,7 +254,7 @@ sub ACTION_track_overlapping {
     my $state          = $self->state;
     $q->param('format_option'     => $overlapping eq 'true' ? 4 : 0);
     $q->param('conf_color_series' => $overlapping eq 'true' ? 1 : 0);
-    $self->render->reconfigure_track($track_name);
+    $self->render->reconfigure_track($q,$track_name);
     $self->session->flush;
     $self->session->unlock;
     return ( 200, 'application/json', {} );    
@@ -848,9 +848,9 @@ sub ACTION_upload_file {
 
     my $return_object = {
     	success		=> $result || 0,
-		error_msg	=> CGI::escapeHTML($msg),
-		tracks		=> $tracks,
-		uploadName	=> $name,
+	error_msg	=> CGI::escapeHTML($msg),
+	tracks		=> $tracks,
+	uploadName	=> $name,
     };
 
     if ($q->param('forcejson')) {
@@ -1101,7 +1101,6 @@ sub ACTION_set_subtracks {
     my $q    = shift;
     my $label= $q->param('label');
     my $subtracks = JSON::from_json($q->param('subtracks'));
-    my $overlap   = $q->param('overlap');
     my $settings  = $self->state;
     $self->state->{subtracks}{$label} = $subtracks;
     $self->session->flush;
